arvore <-
function(...) {
	# Se .ArvoReRunning existe, ento o ArvoRe j est em execuo...
	if (!exists(".ArvoReRunning", envir = globalenv() )) {
	
		# Verifica a presena dos pacotes necessrios
		.pacotespresentes <- as.character(as.data.frame(installed.packages())$Package)
		.pacotesnecessarios <- c("abind","gplots","gdata","stringr","tcltk","tcltk2","triangle")
		
		for (i in .pacotesnecessarios ) {
			if ( sum( .pacotespresentes == i ) == 0 ) { 
				install.packages(i)
			} 
		}
		rm(i,.pacotespresentes,.pacotesnecessarios)
		
		# ArvoRe Settings
		require(tcltk) || stop("tcltk support is absent")
		require(tcltk2) || stop("tcltk2 support is absent")
		require(stringr) || stop("stringr support is absent")
		require(abind) || stop("abind support is absent")
		require(gplots) || stop("gplots support is absent")
		require(gdata) || stop("gdata support is absent")
		require(triangle) || stop("triangle support is absent")
				
		###############################################################################
		# THE GAME!!
		###############################################################################
		# Configuration variables
		.EnvironmentArvoRe <- globalenv()
		.EnvironmentArvore.Secure <- new.env(parent = globalenv())
		.arvore.version <- "Alfa-0.1.15"							# The ArvoRe version
		.arvore.release.date <- "January 09, 2013 01:37:27 PM "		# The ArvoRe version date
		.modeltypeArvore <- "CE" 									# Default calculation method "Simple" # "CEA"
		.workstatus <- "saved"										# File status
		.opennedfile <- "newfile"									# File name
		.digits <- 3												# Decimal places
		.init.objects <- objects(all.names = TRUE, 
									envir = .EnvironmentArvoRe)		# Objetos existentes antes de abrir o ArvoRe
		.treeangle <- "squared"										# Tipo de ngulos exibidos para a rvore
		.notesconf <- 0												# Mostrar notas no grfico { 1 = yes, 0 = no }
		.probabilityconf <- 1										# Mostrar probabilidades no grfico { 1 = yes, 0 = no }
		.payoffsconf <- 1											# Mostrar payoffs no grfico { 1 = yes, 0 = no }
		.node.name.font.size <- 12									# Tamanho da fonte para o nome do nodo exibido no grfico.
		.payoffs.font.size	<- 8									# Tamanho da fonte para payoffs do nodo exibido no grfico.
		.notes.font.size <- 6										# Tamanho da fonte para comentrios do nodo exibido no grfico.
		.absorventstateconf <- 1									# Estados absorventes da cadeia de Markov so interpretados como MORTE.
		.syntaxfile <- paste(tempdir(),"\\", "syntax.R", sep="")    # O arquivo de sintaxe do arvoRe
		
		assign(".EnvironmentArvoRe", .EnvironmentArvoRe, env = .GlobalEnv)
		assign(".EnvironmentArvore.Secure", .EnvironmentArvore.Secure, env = .GlobalEnv)
		assign(".arvore.version", .arvore.version, env = .GlobalEnv)
		assign(".modeltypeArvore", .modeltypeArvore, env = .GlobalEnv)
		assign(".workstatus", .workstatus, env = .GlobalEnv)
		assign(".opennedfile", .opennedfile, env = .GlobalEnv)
		assign(".digits", .digits, env = .GlobalEnv)
		assign(".init.objects", .init.objects, env = .GlobalEnv)
		assign(".treeangle", .treeangle, env = .GlobalEnv)
		assign(".notesconf", .notesconf, env = .GlobalEnv)
		assign(".probabilityconf", .probabilityconf, env = .GlobalEnv)
		assign(".payoffsconf", .payoffsconf, env = .GlobalEnv)
		assign(".node.name.font.size", .node.name.font.size, env = .GlobalEnv)
		assign(".node.name.font.size", .node.name.font.size, env = .GlobalEnv)
		assign(".payoffs.font.size", .payoffs.font.size, env = .GlobalEnv)
		assign(".notes.font.size", .notes.font.size, env = .GlobalEnv)
		assign(".absorventstateconf", .absorventstateconf, env = .GlobalEnv)
		assign(".syntaxfile", .syntaxfile, env = .GlobalEnv)
		assign(".stage", 0, env = .GlobalEnv)
		assign(".stage.cost", 0, env = .GlobalEnv)
		assign(".stage.eff", 0, env = .GlobalEnv)
		assign(".stage.reward", 0, env = .GlobalEnv)
		assign(".total.cost", 0, env = .GlobalEnv)
		assign(".total.eff", 0, env = .GlobalEnv)
		assign(".total.reward", 0, env = .GlobalEnv)
		
# 		assign("", x, env = .GlobalEnv)

		###############################################################################
		# The Tk things
		###############################################################################
#  		carregaTclpath()	# Carrega extenses da Tcltk
			lib.but <- ""
			iconpath <- "/arvoRe/icons/New.png"
			for (i in 1:length(.libPaths())) {
				if ( file.exists( paste(.libPaths()[i],iconpath,sep="") ) && nchar(lib.but) == 0 ) {
					lib.but <- .libPaths()[i]
				}
			}
			if (nchar(lib.but) != 0) {	
				caminho <- file.path(paste(lib.but,"/arvoRe/tklibs/BWidget_1.8.0",sep=""))
				addTclPath(caminho)
				caminho <- file.path(paste(lib.but,"/arvoRe/tklibs/Tktable2.9",sep=""))
				addTclPath(caminho)
				caminho <- file.path(paste(lib.but,"/arvoRe/tklibs/Img1.3",sep=""))
				addTclPath(caminho)				
			} else {
				cat("FATAL ERROR : Tcllibs not found in library path \n")
			}

		tclRequire("Tk", warn = TRUE)
#  		tclRequire("Img")
		try(.Tcl("package require Img"))
		tclRequire("BWidget", warn = TRUE)
		#---------------------------------------------------------------------- 
		# Create a new decision tree
		new.tree()
		
		# Set the initial syntax file
		commandstringformat <- paste('# -----------------------------------------------------------------------------')
		add.Syntax(commandstringformat)
		commandstringformat <- paste('# Script Name         : my_tree.R')
		add.Syntax(commandstringformat)
		commandstringformat <- paste('# Author              : Xxxx Xxxxxxxxxxx')
		add.Syntax(commandstringformat)
		commandstringformat <- paste('# Date last Modified  : Mmm Dd Yyyy')
		add.Syntax(commandstringformat)
		commandstringformat <- paste('# Purpose/Description : Some description for your script')
		add.Syntax(commandstringformat)
		commandstringformat <- paste('# Notes               : Some notes for your script')
		add.Syntax(commandstringformat)
		commandstringformat <- paste('# -----------------------------------------------------------------------------')
		add.Syntax(commandstringformat)

		commandstringformat <- paste("clearTreeTkArvore(TheTree) # Clear the current tree")
		add.Syntax(commandstringformat)
		commandstringformat <- paste("new.tree() # Create a empty tree")
		add.Syntax(commandstringformat)
		commandstringformat <- paste("theTreeTkArvore(TheTree)")
		add.Syntax(commandstringformat)
		commandstringformat <- paste("atualiza.grafico()")
		add.Syntax(commandstringformat)
				
		# Set Running flag to TRUE
		.ArvoReRunning <- TRUE
		
		# The splashscreen
		splashscreenArvoRe()
		
		# The main window
		tt <- tktoplevel()
		
		# Send tt addres to .EnvironmentArvoRe
		assign("tt", tt, .EnvironmentArvoRe)
		
		.Windowtitle <- paste("ArvoRe - Main Window", " - [", .opennedfile, "]", sep = "")
		.Frametitle1 <- " Tree View "
		.Frametitle2 <- paste("ArvoRe - version ", .arvore.version, " | ", 
								" | ", "Running on R ", getRversion(), " ",
								sep="")
		.Frametitle3 <- " Node Configuration "
		
		tkwm.title(tt, .Windowtitle)
		
		# Set max and min size to main ArvoRe window
		tkwm.minsize(tt,640,480)
# 		tkwm.maxsize(tt,1024,768)
		
		# The Frames
		frameOverall <- tkframe(tt)
		frameBottons <- tkframe(frameOverall,relief="groove",borderwidth=2)
		frameUpper <- tkframe(frameOverall,relief="groove",borderwidth=2)
		
			frameUpperLeft <- tkframe(frameUpper,relief="groove",borderwidth=2)
			
				frameUpperLeftUp <- tkframe(frameUpperLeft,relief="groove",borderwidth=2)
				frameUpperLeftDown <- tkframe(frameUpperLeft,relief="groove",borderwidth=2)
				
			frameUpperRigth <- tkframe(frameUpper,relief="groove",borderwidth=2)
			tkpack(tklabel(frameUpperRigth,text = .Frametitle1))
		
		frameLower <- tkframe(frameOverall,relief="sunken",borderwidth=2)
		tkpack(tklabel(frameLower,text = .Frametitle2, justify = "left"), fill = "x", expand = 0, side = "left")
		
		tkpack(frameBottons, anchor = "nw", expand = 0, side = "top")#, fill = "x")
		tkpack(frameUpperLeft, side = "left", expand = 0, fill = "y")
		tkpack(frameUpperRigth, side = "left", expand = 1, fill = "both")
		tkpack(frameUpper, anchor = "n", side = "top", expand = 1, fill = "both")
		tkpack(tklabel(frameOverall,text=" "))
		tkpack(frameLower, anchor = "sw", fill = "x", expand = 0, side = "bottom")
		tkpack(tklabel(frameOverall,text=" "))
		tkpack(frameOverall, anchor = "center", expand = 1, fill = "both")
		
		# The Menu
		topMenu <- tkmenu(tt)
		tkconfigure(tt,menu=topMenu)
		fileMenu <- tkmenu(topMenu,tearoff=FALSE)
			tkadd(fileMenu,"command",label="New           Ctrl+N",command=function() new.file.bot())
			tkadd(fileMenu,"command",label="Open...       Ctrl+O",command=function() load.file.arv())
			tkadd(fileMenu,"command",label="Save         Ctrl+S",command=function() save.file.arv())
			tkadd(fileMenu,"command",label="Save as... Ctrl+Alt+S",command=function() save.as.file.arv())
			tkadd(fileMenu,"separator")
			tkadd(fileMenu,"command",label="Export...    Ctrl+E",command=function() export.tree.graph())
			tkadd(fileMenu,"separator")
			tkadd(fileMenu,"command",label="Exit            Esc",command=function() sair())
		tkadd(topMenu,"cascade",label="File",menu=fileMenu)
		
		editMenu <- tkmenu(topMenu,tearoff=FALSE)
			tkadd(editMenu,"command",label="Undo", command=function() changedofunction(TheTree, .modeltypeArvore, .EnvironmentArvore.Secure))
			tkadd(editMenu,"command",label="Redo", command=function() changedofunction(TheTree, .modeltypeArvore, .EnvironmentArvore.Secure))
			tkadd(editMenu,"separator")
			tkadd(editMenu,"command",label="Cut", command=function() naoimplementado())
			tkadd(editMenu,"command",label="Copy", command=function() naoimplementado())
			tkadd(editMenu,"command",label="Paste", command=function() naoimplementado())
			tkadd(editMenu,"separator")
			tkadd(editMenu,"command",label="Remove", command=function() removenodewindows())
			tkadd(editMenu,"separator")
			tkadd(editMenu,"command", state="disabled",label="Cut subtree",command=function() naoimplementado())
			tkadd(editMenu,"command", state="disabled",label="Copy subtree",command=function() naoimplementado())
			tkadd(editMenu,"command", state="disabled",label="Paste subtree",command=function() naoimplementado())
			tkadd(editMenu,"separator")
			tkadd(editMenu,"command",label="Remove subtree", command=function() removenodewindows())
			tkadd(editMenu,"separator")
			tkadd(editMenu,"command",label="Variables...", command=function() dialog.variable.window())
			tkadd(editMenu,"separator")
			tkadd(editMenu,"command",label="Settings...", command=function() properties.tree())
		tkadd(topMenu,"cascade",label="Edit",menu=editMenu)
		
		modelMenu <- tkmenu(topMenu,tearoff=FALSE)
			tkadd(modelMenu,"command",label="Simple decision tree", command=function() set.model.type("SD") )
			tkadd(modelMenu,"separator")
			tkadd(modelMenu,"command",label="Cost-effectiveness tree", command=function() set.model.type("CE") )
		
		tkadd(topMenu,"cascade",label="Model",menu=modelMenu)
		
		analysisMenu <- tkmenu(topMenu,tearoff=FALSE)
			tkadd(analysisMenu,"command",label="Expected values (Roll Back)",command=function() show.summary.rollback.window())
			tkadd(analysisMenu,"separator")
			tkadd(analysisMenu,"command",label="ACE Summary (ICER)...",command=function() acewindow(TheTree))
			tkadd(analysisMenu,"command",label="Cost-Effectiveness Plane",command=function() planoacewindow(TheTree))
			tkadd(analysisMenu,"command",label="Incremental Net Benefit (INB)",command=function() inbwindow(TheTree))
			tkadd(analysisMenu,"separator")
			tkadd(analysisMenu,"command",label="Tree summary",command=function() show.summary.tree.window())
			tkadd(analysisMenu,"separator")
			tkadd(analysisMenu,"command",label="Check probilities",command=function() show.prob.check.window(TheTree))
		tkadd(topMenu,"cascade",label="Analysis",menu=analysisMenu)
		
		windowMenu <- tkmenu(topMenu,tearoff=FALSE)
			tkadd(windowMenu,"command",label="Zoom +...",command=function() zoom.in.but(imgHeight))
			tkadd(windowMenu,"command",label="Zoom -...",command=function() zoom.out.but(imgHeight))
			tkadd(windowMenu,"separator")
			tkadd(windowMenu,"command",label="Window resolution...",command=function() naoimplementado())
		tkadd(topMenu,"cascade",label="Window",menu=windowMenu)
		
		helpMenu <- tkmenu(topMenu,tearoff=FALSE)
			tkadd(helpMenu,"command",label="Help",command=function() help.start())
			tkadd(helpMenu,"separator")
			tkadd(helpMenu,"command",label="About arvoRe",command=function() sobre(.arvore.version, .arvore.release.date))
		tkadd(topMenu,"cascade",label="Help",menu=helpMenu)
		
		# The top bottons
		.Height.but <- 3
		.Width.but <- 7
		.Height.img.but <- 32
		.Width.img.but <- 32
		
		#	New button
			icon.but <- ""
			iconpath <- "/arvoRe/icons/New.png"
			for (i in 1:length(.libPaths())) {
				if ( file.exists( paste(.libPaths()[i],iconpath,sep="") ) && nchar(icon.but) == 0 ) {
					icon.but <- paste(.libPaths()[i],iconpath,sep="")
				}
			}
			if (nchar(icon.but) != 0) {
				icn <- tkimage.create("photo", file=icon.but)
				new.but <- tkbutton(frameBottons, image=icn, width=.Width.img.but, height=.Height.img.but, 
									command=function() new.file.bot())
				tcl("DynamicHelp::add", new.but, "-type", "balloon", "-text", "New work")
		
			} else {
				new.but <- tkbutton(frameBottons, text="Novo", width=.Width.but, height=.Height.but, command=function() new.file.bot())
				tcl("DynamicHelp::add", new.but, "-type", "balloon", "-text", "New work")
			}
		
		#	Open button
			icon.but <- ""
			iconpath <- "/arvoRe/icons/Open.png"
			for (i in 1:length(.libPaths())) {
				if ( file.exists( paste(.libPaths()[i],iconpath,sep="") ) && nchar(icon.but) == 0 ) {
					icon.but <- paste(.libPaths()[i],iconpath,sep="")
				}
			}
			if (nchar(icon.but) != 0) {
				icn <- tkimage.create("photo", file=icon.but)
				open.but <- tkbutton(frameBottons, image=icn, width=.Width.img.but, height=.Height.img.but, command=function() load.file.arv())
				tcl("DynamicHelp::add", open.but, "-type", "balloon", "-text", "Open a work")
			} else {
				open.but <- tkbutton(frameBottons, text="Abrir", width=.Width.img.but, height=.Height.img.but, command=function() load.file.arv())
				tcl("DynamicHelp::add", open.but, "-type", "balloon", "-text", "Open a work")
			}
		
		#	Save button
			icon.but <- ""
			iconpath <- "/arvoRe/icons/Save.png"
			for (i in 1:length(.libPaths())) {
				if ( file.exists( paste(.libPaths()[i],iconpath,sep="") ) && nchar(icon.but) == 0 ) {
					icon.but <- paste(.libPaths()[i],iconpath,sep="")
				}
			}
			if (nchar(icon.but) != 0) {
				icn <- tkimage.create("photo", file=icon.but)
				save.but <- tkbutton(frameBottons, image=icn, width=.Width.img.but, height=.Height.img.but, command=function() save.file.arv())
				tcl("DynamicHelp::add", save.but, "-type", "balloon", "-text", "Save current work")
			} else {
				save.but <- tkbutton(frameBottons, text="Salvar", width=.Width.img.but, height=.Height.img.but, command=function() save.file.arv())
				tcl("DynamicHelp::add", save.but, "-type", "balloon", "-text", "Save current work")
		
			}
		
		#	Save As button
			icon.but <- ""
			iconpath <- "/arvoRe/icons/SaveAs.png"
			for (i in 1:length(.libPaths())) {
				if ( file.exists( paste(.libPaths()[i],iconpath,sep="") ) && nchar(icon.but) == 0 ) {
					icon.but <- paste(.libPaths()[i],iconpath,sep="")
				}
			}
			if (nchar(icon.but) != 0) {
				icn <- tkimage.create("photo", file=icon.but)
				saveas.but <- tkbutton(frameBottons, image=icn, width=.Width.img.but, height=.Height.img.but, command=function() save.as.file.arv())
				tcl("DynamicHelp::add", saveas.but, "-type", "balloon", "-text", "Save as...")
			} else {
				saveas.but <- tkbutton(frameBottons, text="Salvar \n como...", width=.Width.img.but, height=.Height.img.but, command=function() save.as.file.arv())
				tcl("DynamicHelp::add", saveas.but, "-type", "balloon", "-text", "Save as...")
			}
		
		#	Undo button
			icon.but <- ""
			iconpath <- "/arvoRe/icons/Undo.png"
			for (i in 1:length(.libPaths())) {
				if ( file.exists( paste(.libPaths()[i],iconpath,sep="") ) && nchar(icon.but) == 0 ) {
					icon.but <- paste(.libPaths()[i],iconpath,sep="")
				}
			}
			if (nchar(icon.but) != 0) {
				icn <- tkimage.create("photo", file=icon.but)
				undo.but <- tkbutton(frameBottons, image=icn, width=.Width.img.but, height=.Height.img.but, command=function() changedofunction(TheTree, .modeltypeArvore, .EnvironmentArvore.Secure))
				tcl("DynamicHelp::add", undo.but, "-type", "balloon", "-text", "Undo")
			} else {
				undo.but <- tkbutton(frameBottons, text="<=", width=.Width.img.but, height=.Height.img.but, command=function() changedofunction(TheTree, .modeltypeArvore, .EnvironmentArvore.Secure))
				tcl("DynamicHelp::add", undo.but, "-type", "balloon", "-text", "Undo")
			}
		
		#	Redo button
			icon.but <- ""
			iconpath <- "/arvoRe/icons/Redo.png"
			for (i in 1:length(.libPaths())) {
				if ( file.exists( paste(.libPaths()[i],iconpath,sep="") ) && nchar(icon.but) == 0 ) {
					icon.but <- paste(.libPaths()[i],iconpath,sep="")
				}
			}
			if (nchar(icon.but) != 0) {
				icn <- tkimage.create("photo", file=icon.but)
				redo.but <- tkbutton(frameBottons, image=icn, width=.Width.img.but, height=.Height.img.but, command=function() changedofunction(TheTree, .modeltypeArvore, .EnvironmentArvore.Secure))
				tcl("DynamicHelp::add", redo.but, "-type", "balloon", "-text", "Redo")
			} else {
				redo.but <- tkbutton(frameBottons, text="=>", width=.Width.img.but, height=.Height.img.but, command=function() changedofunction(TheTree, .modeltypeArvore, .EnvironmentArvore.Secure))
				tcl("DynamicHelp::add", redo.but, "-type", "balloon", "-text", "Redo")
			}
	
		#	Markov properties button
			icon.but <- ""
			iconpath <- "/arvoRe/icons/Markov.png"
			for (i in 1:length(.libPaths())) {
				if ( file.exists( paste(.libPaths()[i],iconpath,sep="") ) && nchar(icon.but) == 0 ) {
					icon.but <- paste(.libPaths()[i],iconpath,sep="")
				}
			}
			if (nchar(icon.but) != 0) {
				icn <- tkimage.create("photo", file=icon.but)
				markov.prop.but <- tkbutton(frameBottons, image=icn, width=.Width.img.but, height=.Height.img.but, command=function() markov.nodes.properties(TheTree, .EnvironmentArvoRe))
				tcl("DynamicHelp::add", markov.prop.but, "-type", "balloon", "-text", "Markov state settings...")
			} else {
				markov.prop.but <- tkbutton(frameBottons, text="Markov \n Sim.", width=.Width.img.but, height=.Height.img.but, command=function() markov.nodes.properties(TheTree, .EnvironmentArvoRe))
				tcl("DynamicHelp::add", markov.prop.but, "-type", "balloon", "-text", "Markov state settings...")
			}
		
		#	Variable button
			icon.but <- ""
			iconpath <- "/arvoRe/icons/Variable.png"
			for (i in 1:length(.libPaths())) {
				if ( file.exists( paste(.libPaths()[i],iconpath,sep="") ) && nchar(icon.but) == 0 ) {
					icon.but <- paste(.libPaths()[i],iconpath,sep="")
				}
			}
			if (nchar(icon.but) != 0) {
				icn <- tkimage.create("photo", file=icon.but)
				variable.but <- tkbutton(frameBottons, image=icn, width=.Width.img.but, height=.Height.img.but, command=function() dialog.variable.window())
				tcl("DynamicHelp::add", variable.but, "-type", "balloon", "-text", "Variables...")
			} else {
				variable.but <- tkbutton(frameBottons, text="Markov \n Sim.", width=.Width.img.but, height=.Height.img.but, command=function() dialog.variable.window())
				tcl("DynamicHelp::add", variable.but, "-type", "balloon", "-text", "Variables...")
			}
			
		#	Distributions button
			icon.but <- ""
			iconpath <- "/arvoRe/icons/Distribution.png"
			for (i in 1:length(.libPaths())) {
				if ( file.exists( paste(.libPaths()[i],iconpath,sep="") ) && nchar(icon.but) == 0 ) {
					icon.but <- paste(.libPaths()[i],iconpath,sep="")
				}
			}
			if (nchar(icon.but) != 0) {
				icn <- tkimage.create("photo", file=icon.but)
				distribution.but <- tkbutton(frameBottons, image=icn, width=.Width.img.but, height=.Height.img.but, command=function() dialog.distribution.window())
				tcl("DynamicHelp::add", distribution.but, "-type", "balloon", "-text", "Distributions...")
			} else {
				distribution.but <- tkbutton(frameBottons, text="Distribution", width=.Width.img.but, height=.Height.img.but, command=function() dialog.distribution.window())
				tcl("DynamicHelp::add", distribution.but, "-type", "balloon", "-text", "Distributions...")
			}
		
		#	Simulation button
			icon.but <- ""
			iconpath <- "/arvoRe/icons/Simulation.png"
			for (i in 1:length(.libPaths())) {
				if ( file.exists( paste(.libPaths()[i],iconpath,sep="") ) && nchar(icon.but) == 0 ) {
					icon.but <- paste(.libPaths()[i],iconpath,sep="")
				}
			}
			if (nchar(icon.but) != 0) {
				icn <- tkimage.create("photo", file=icon.but)
				simulation.but <- tkbutton(frameBottons, image=icn, width=.Width.img.but, height=.Height.img.but, command=function() dialog.simulation.window())
				tcl("DynamicHelp::add", simulation.but, "-type", "balloon", "-text", "Simulation... (MCMC)")
			} else {
				simulation.but <- tkbutton(frameBottons, text="Markov \n Sim.", width=.Width.img.but, height=.Height.img.but, command=function() dialog.simulation.window())
				tcl("DynamicHelp::add", simulation.but, "-type", "balloon", "-text", "Simulation... (MCMC)")
			}
		
		#	Roll-Back button
			icon.but <- ""
			iconpath <- "/arvoRe/icons/Ball.png"
			for (i in 1:length(.libPaths())) {
				if ( file.exists( paste(.libPaths()[i],iconpath,sep="") ) && nchar(icon.but) == 0 ) {
					icon.but <- paste(.libPaths()[i],iconpath,sep="")
				}
			}
			if (nchar(icon.but) != 0) {
				icn <- tkimage.create("photo", file=icon.but)
				rollback.but <- tkbutton(frameBottons, image=icn, width=.Width.img.but, height=.Height.img.but, command=function() show.summary.rollback.window())
				tcl("DynamicHelp::add", rollback.but, "-type", "balloon", "-text", "Roll-back")
			} else {
				rollback.but <- tkbutton(frameBottons, text="Roll-Back", width=.Width.img.but, height=.Height.img.but, command=function() show.summary.rollback.window())
				tcl("DynamicHelp::add", rollback.but, "-type", "balloon", "-text", "Roll-back")
			}
		
		#	Sensitivity Analysis button 1-way
			icon.but <- ""
			iconpath <- "/arvoRe/icons/Graph.png"
			for (i in 1:length(.libPaths())) {
				if ( file.exists( paste(.libPaths()[i],iconpath,sep="") ) && nchar(icon.but) == 0 ) {
					icon.but <- paste(.libPaths()[i],iconpath,sep="")
				}
			}
			if (nchar(icon.but) != 0) {
				icn <- tkimage.create("photo", file=icon.but)
				sa.but <- tkbutton(frameBottons, image=icn, width=.Width.img.but, height=.Height.img.but, command=function() dialog.sensitivityanalysis.w1.window())
				tcl("DynamicHelp::add", sa.but, "-type", "balloon", "-text", "Sensitivity Analysis 1-way")
			} else {
				sa.but <- tkbutton(frameBottons, text="Sensitivity Analysis 1-way", width=.Width.img.but, height=.Height.img.but, command=function() dialog.sensitivityanalysis.w1.window())
				tcl("DynamicHelp::add", sa.but, "-type", "balloon", "-text", "Sensitivity Analysis 1-way")
			}
		
		#	Sensitivity Analysis button 2-way
			icon.but <- ""
			iconpath <- "/arvoRe/icons/Graph2.png"
			for (i in 1:length(.libPaths())) {
				if ( file.exists( paste(.libPaths()[i],iconpath,sep="") ) && nchar(icon.but) == 0 ) {
					icon.but <- paste(.libPaths()[i],iconpath,sep="")
				}
			}
			if (nchar(icon.but) != 0) {
				icn <- tkimage.create("photo", file=icon.but)
				sa2.but <- tkbutton(frameBottons, image=icn, width=.Width.img.but, height=.Height.img.but, command=function() dialog.sensitivityanalysis.w2.window())
				tcl("DynamicHelp::add", sa2.but, "-type", "balloon", "-text", "Sensitivity Analysis 2-way")
			} else {
				sa2.but <- tkbutton(frameBottons, text="Sensitivity Analysis 2-way", width=.Width.img.but, height=.Height.img.but, command=function() dialog.sensitivityanalysis.w2.window())
				tcl("DynamicHelp::add", sa2.but, "-type", "balloon", "-text", "Sensitivity Analysis 2-way")
			}
			
		#	Sensitivity Analysis button n-way
			icon.but <- ""
			iconpath <- "/arvoRe/icons/Graph3.png"
			for (i in 1:length(.libPaths())) {
				if ( file.exists( paste(.libPaths()[i],iconpath,sep="") ) && nchar(icon.but) == 0 ) {
					icon.but <- paste(.libPaths()[i],iconpath,sep="")
				}
			}
			if (nchar(icon.but) != 0) {
				icn <- tkimage.create("photo", file=icon.but)
				san.but <- tkbutton(frameBottons, image=icn, width=.Width.img.but, height=.Height.img.but, command=function() dialog.sensitivityanalysis.wn.window())
				tcl("DynamicHelp::add", san.but, "-type", "balloon", "-text", "Sensitivity Analysis multi-way")
			} else {
				san.but <- tkbutton(frameBottons, text="Sensitivity Analysis 2-way", width=.Width.img.but, height=.Height.img.but, command=function() dialog.sensitivityanalysis.wn.window())
				tcl("DynamicHelp::add", san.but, "-type", "balloon", "-text", "Sensitivity Analysis multi-way")
			}
		
		#	Zoom In button
			icon.but <- ""
			iconpath <- "/arvoRe/icons/ZoomPlus.png"
			for (i in 1:length(.libPaths())) {
				if ( file.exists( paste(.libPaths()[i],iconpath,sep="") ) && nchar(icon.but) == 0 ) {
					icon.but <- paste(.libPaths()[i],iconpath,sep="")
				}
			}
			if (nchar(icon.but) != 0) {
				icn <- tkimage.create("photo", file=icon.but)
				zoom.in <- tkbutton(frameBottons, image=icn, width=.Width.img.but, height=.Height.img.but, command=function() zoom.in.but(imgHeight))
				tcl("DynamicHelp::add", zoom.in, "-type", "balloon", "-text", "Zoom more")
			} else {
				zoom.in <- tkbutton(frameBottons, text="Zoom \n +", width=.Width.img.but, height=.Height.img.but, command=function() zoom.in.but(imgHeight))
				tcl("DynamicHelp::add", zoom.in, "-type", "balloon", "-text", "Zoom more")
			}
		
		#	Zoom Out button
			icon.but <- ""
			iconpath <- "/arvoRe/icons/ZoomMinus.png"
			for (i in 1:length(.libPaths())) {
				if ( file.exists( paste(.libPaths()[i],iconpath,sep="") ) && nchar(icon.but) == 0 ) {
					icon.but <- paste(.libPaths()[i],iconpath,sep="")
				}
			}
			if (nchar(icon.but) != 0) {
				icn <- tkimage.create("photo", file=icon.but)
				zoom.out <- tkbutton(frameBottons, image=icn, width=.Width.img.but, height=.Height.img.but, command=function() zoom.out.but(imgHeight))
				tcl("DynamicHelp::add", zoom.out, "-type", "balloon", "-text", "Zoom minus")
			} else {
				zoom.out <- tkbutton(frameBottons, text="Zoom \n -", width=.Width.img.but, height=.Height.img.but, command=function() zoom.out.but(imgHeight))
				tcl("DynamicHelp::add", zoom.out, "-type", "balloon", "-text", "Zoom minus")
			}
		
		#	Syntax button
			icon.but <- ""
			iconpath <- "/arvoRe/icons/New.png"
			for (i in 1:length(.libPaths())) {
				if ( file.exists( paste(.libPaths()[i],iconpath,sep="") ) && nchar(icon.but) == 0 ) {
					icon.but <- paste(.libPaths()[i],iconpath,sep="")
				}
			}
			if (nchar(icon.but) != 0) {
				icn <- tkimage.create("photo", file=icon.but)
				syntax.but <- tkbutton(frameBottons, image=icn, width=.Width.img.but, height=.Height.img.but, command=function(...) show.Syntax(syntax.file.array) )
				tcl("DynamicHelp::add", syntax.but, "-type", "balloon", "-text", "Show the code")
			} else {
				syntax.but <- tkbutton(frameBottons, text="Sair", width=.Width.img.but, height=.Height.img.but, command=function(...) show.Syntax(syntax.file.array) )
				tcl("DynamicHelp::add", syntax.but, "-type", "balloon", "-text", "\"Show the code \"")
			}
		
		#	Exit button
			icon.but <- ""
			iconpath <- "/arvoRe/icons/Exit.png"
			for (i in 1:length(.libPaths())) {
				if ( file.exists( paste(.libPaths()[i],iconpath,sep="") ) && nchar(icon.but) == 0 ) {
					icon.but <- paste(.libPaths()[i],iconpath,sep="")
				}
			}
			if (nchar(icon.but) != 0) {
				icn <- tkimage.create("photo", file=icon.but)
				exit.but <- tkbutton(frameBottons, image=icn, width=.Width.img.but, height=.Height.img.but, command=function() sair())
				tcl("DynamicHelp::add", exit.but, "-type", "balloon", "-text", "Exit program")
			} else {
				exit.but <- tkbutton(frameBottons, text="Sair", width=.Width.img.but, height=.Height.img.but, command=function() sair())
				tcl("DynamicHelp::add", exit.but, "-type", "balloon", "-text", "\"Exit program \"")
			}
		
		separator1 <- tklabel(frameBottons, text = " ")
		separator2 <- tklabel(frameBottons, text = " ")
		separator3 <- tklabel(frameBottons, text = " ")
		separator4 <- tklabel(frameBottons, text = " ")
		separator5 <- tklabel(frameBottons, text = " ")
		separator6 <- tklabel(frameBottons, text = " ")
		separator7 <- tklabel(frameBottons, text = " ")
		
		tkgrid(new.but, open.but, save.but, saveas.but, separator1,
				undo.but, redo.but, separator2,
				markov.prop.but, variable.but, distribution.but, separator3,
				simulation.but, rollback.but, separator4,
				sa.but, sa2.but, san.but, separator5,
				zoom.in, zoom.out, separator6,
				syntax.but, separator7,
				exit.but, 
				sticky = "nw")
		
		tkconfigure(new.but, activebackground = "white")
		tkflash(new.but)
		
		# The tree structure view
		frameUpperLeftUpUp <- tkframe(frameUpperLeftUp,relief="groove",borderwidth=0)
		frameUpperLeftUpBotton <- tkframe(frameUpperLeftUp,relief="groove",borderwidth=0)
		
		xScr       <- tkscrollbar(frameUpperLeftUpBotton,command=function(...)tkxview(treeWidget,...),orient="horizontal")
		yScr       <- tkscrollbar(frameUpperLeftUpUp,command=function(...)tkyview(treeWidget,...))
		treeWidget <- tkwidget(frameUpperLeftUpUp,"Tree", deltax = 25, deltay = 20,
										xscrollcommand=function(...)tkset(xScr,...), 
										yscrollcommand=function(...)tkset(yScr,...),
										width=30,height=15)
										
		# tkgrid(treeWidget, yScr,stick="ns")
# #		tkgrid.configure(treeWidget,stick="ns")
# #		tkgrid.configure(yScr,stick="nsw")
		# tkgrid(xScr,stick="we")
# #		tkgrid.configure(xScr,stick="we")
		# tkgrid(frameUpperLeftUp, sticky = "news")
		
		tkpack(treeWidget, anchor = "nw", expand = 1, side = "left", fill = "both")
		tkpack(yScr, anchor = "ne", expand = 1, side = "left", fill = "y")
		tkpack(xScr, anchor = "nw", expand = 1, fill = "x")
		tkpack(frameUpperLeftUpUp, expand = 1, side = "top", fill = "both")
		tkpack(frameUpperLeftUpBotton, expand = 1, side = "bottom", fill = "x")
		tkgrid(frameUpperLeftUp, sticky = "news")
		
		# Send treeWidget addres to .EnvironmentArvoRe
		assign("treeWidget", treeWidget, .EnvironmentArvoRe)
		
		theTreeTkArvore(TheTree)
		
		# The Tree Bottons
		.Height.but <- 2
		.Width.but <- 16
		
		node.name.but <- tkbutton(frameUpperLeftDown, text="Name", width=.Width.but, height=.Height.but, command=function() nodenamewindows())
		node.prob.but <- tkbutton(frameUpperLeftDown, text="Probability", width=.Width.but, height=.Height.but, command=function() probwindows())
		node.playoff.but <- tkbutton(frameUpperLeftDown, text="Values", width=.Width.but, height=.Height.but, command=function() utilitywindows())
		node.type <- tkbutton(frameUpperLeftDown, text="Type", width=.Width.but, height=.Height.but, command=function() typenodewindows())
		node.add <- tkbutton(frameUpperLeftDown, text="Add", width=.Width.but, height=.Height.but, command=function() addnodewindows())
		node.remove <- tkbutton(frameUpperLeftDown, text="Remove", width=.Width.but, height=.Height.but, command=function() removenodewindows())
		node.destiny <- tkbutton(frameUpperLeftDown, text="Destiny", width=.Width.but, height=.Height.but, command=function() destinynodewindows())
		node.notes <- tkbutton(frameUpperLeftDown, text="Commits", width=.Width.but, height=.Height.but, command=function() notesnodewindows())
		
		tkgrid(tklabel(frameUpperLeft,text = .Frametitle3))
		tkgrid(node.name.but, row = 0, column = 0, sticky = "nw")
		tkgrid(node.prob.but, row = 0, column = 1, sticky = "nw")
		tkgrid(node.type, row = 1, column = 0, sticky = "nw")
		tkgrid(node.playoff.but, row = 1, column = 1, sticky = "nw")
		tkgrid(node.add, row = 2, column = 0, sticky = "nw")
		tkgrid(node.remove, row = 2, column = 1, sticky = "nw")
		tkgrid(node.destiny, row = 3, column = 0, sticky = "nw")
		tkgrid(node.notes, row = 3, column = 1, sticky = "nw")
				
		tkgrid(frameUpperLeftDown, sticky = "swe") #, side = "bottom", expand = 1, fill = "both")
		
		# Image window configurations
		Height <- 400
		Width <- 600
		Borderwidth <- 2
		
		# scrollbar objects
		Hscroll <- tkscrollbar(frameUpperRigth, orient="horiz", command = function(...)tkxview(Canvas,...) )
		Vscroll <- tkscrollbar(frameUpperRigth, command = function(...)tkyview(Canvas,...) )
		Canvas <- tkcanvas(frameUpperRigth, relief = "sunken", borderwidth = Borderwidth, 
							width = Width, height = Height,
							xscrollcommand = function(...)tkset(Hscroll,...), 
							yscrollcommand = function(...)tkset(Vscroll,...)
							)
		
		assign("Canvas", Canvas, .EnvironmentArvoRe)
					
		# Pack the scroll bars.
		tkpack(Hscroll, side = "bottom", fill = "x")
		tkpack(Vscroll, side = "right", fill = "y")
		# Pack the canvas
		tkpack(Canvas, anchor = "center", side = "right", fill = "both", expand = 1)
		
		# Image setings.
		imgHeight <- 600
		imgWidth <- 800
		
		assign("imgHeight", imgHeight, .EnvironmentArvoRe)
		assign("imgWidth", imgWidth, .EnvironmentArvoRe)

		# Image file name setings.
		.Filename <- paste(tempdir(),"\\", "arvore.png", sep="")
		
		# unlink(x, recursive = FALSE)
		
		png(file=.Filename, width = imgWidth, height = imgHeight, bg = "white", restoreConsole = FALSE)
			plot.tree(TheTree, line.type = .treeangle, show.probability = .probabilityconf, 
						show.payoffs = .payoffsconf, show.notes = .notesconf, 
						node.name.font.size = .node.name.font.size, payoffs.font.size = .payoffs.font.size, 
						notes.font.size = .notes.font.size)
		dev.off()
		
		image1 <- tclVar()
		tcl("image","create","photo",image1,file=.Filename)
		tkcreate(Canvas, "image", imgWidth/2, imgHeight/2, image = image1, anchor = "center")
		tkconfigure(Canvas, scrollregion = c(0,0,imgWidth,imgHeight))
		file.remove(.Filename)
		
		
		###############################################################################
		# The keys
		###############################################################################
		
		tkbind(tt, "<Escape>",sair)
		tkbind(tt, "<Control_L><n>",new.file.bot)
		tkbind(tt, "<Control_L><o>",load.file.arv)
		tkbind(tt, "<Control_L><Alt_L><s>",save.file.arv)
		tkbind(tt, "<Control_L><s>",save.file.arv)
		tkbind(tt, "<Control_L><e>",naoimplementado)
		tkbind(tt, "<F5>",refreshF5)
		
		
		###############################################################################
		
		posiciona.janela.tela(tt)
		tkfocus(tt)
		tkwm.deiconify(tt)
	} else {
		msg <- paste("The ArovoRe program is still running.")
		tkmessageBox(message = msg, icon="warning", title = "ArvoRe - WARNING")
	}	
}
